@@ -9,37 +9,43 @@
 
 import cdsapi
 import os
-import sys
 
-from .base import FileSource
+from .base import FileSource, APIKeyPrompt
 from climetlab.core.caching import temp_file
-import getpass
 
 
-MESSAGE = """{error}
+APIRC = "key: {key}\nurl: https://cds.climate.copernicus.eu/api/v2"
 
+MESSAGE = """
 An API key is needed to access this dataset. Please visit
 https://cds.climate.copernicus.eu/ to register or sign-in,
 and visit https://cds.climate.copernicus.eu/api-how-to to
 retrieve you API key.
 
 Once this is done, please paste your key in the input field below
-and press <return>.
-
+and press *ENTER*.
 """
 
-APIRC = "key: {key}\nurl: https://cds.climate.copernicus.eu/api/v2"
+class CDSAPI(APIKeyPrompt):
+
+    text_message = MESSAGE
+
+    markdown_message = MESSAGE
+
+    rcfile = "~/.cdsapirc"
+    prompt = "CDS api key"
+
+    def validate(self, text):
+        uid, key = text.strip().split(':')
+        return APIRC.format(key="%s:%s" % (uid, key))
 
 
 def client():
     try:
         return cdsapi.Client()
     except Exception as e:
-        if str(e).endswith(".cdsapirc"):
-            print(MESSAGE.format(error=str(e)), file=sys.stderr)
-            key = getpass.getpass("CDS api key: ")
-            with open(os.path.expanduser("~/.cdsapirc"), "w") as f:
-                print(APIRC.format(key=key), file=f)
+        if ".cdsapirc" in str(e):
+            CDSAPI().ask_user_and_save()
             return cdsapi.Client()
         else:
             raise
